==> stylight-1.0.1.tar.gz: lib/stylight.dart <==
library stylight;

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

export 'website.dart';

part 'grid.dart';
part 'essentials.dart';

/*

Disclaimer:
Yes I know the TextTheme class, but i prefer having a "faster to implement" version for fast development

 */

class Sty {

  static final Sty sty = new Sty();

  // ignore: empty_constructor_bodies
  Sty() {

  }

  ThemeData get theme {
    return ThemeData(brightness: Brightness.dark, primarySwatch: primary, accentColor: Hues.Blue.hard);
  }

}

enum Hues {

  Blue,
  Red,
  Green,
  Yellow,
  Violet,
  Orange

}

//Using these font colors will probably replace the requirement of opacity in text
Color get textColor1 => primary[100];
Color get textColor2 => primary[200];
Color get textColor3 => primary[300];
Color get textColor4 => primary[400];

enum TextStyles {

  Title1,
  Title2,
  Title3,
  Header,
  SubHeader,
  Body,
  Footnote

}

extension TextStylesExt on TextStyles {

  static TextTheme get textTheme{
    return TextTheme(
        bodyText1: headline, bodyText2: body, subtitle1: subHeadline,
        subtitle2: subHeadline, headline6: headline, headline5: title3,
        headline4: title2, headline3: title1, headline2: title1,
        headline1: title1
    );
  }

  static const double _textBodySize = 13;
  static const double _textBodyHeight = 16;

  static const double _textHeadlineSize = 13;
  static const double _textHeadlineHeight = 16;
  static const double _textSubHeadlineSize = 11;
  static const double _textSubHeadlineHeight = 14;

  static const double _textTitle3Size = 15;
  static const double _textTitle3Height = 20;
  static const double _textTitle2Size = 17;
  static const double _textTitle2Height = 22;
  static const double _textTitle1Size = 22;
  static const double _textTitle1Height = 26;

  static const double _textCaptionFootnoteSize = 10;
  static const double _textCaptionFootnoteHeight = 13;


  static TextStyle get title1 => TextStyle(fontSize: _textTitle1Size, height: _textTitle1Height, fontWeight: FontWeight.normal, color: textColor1);
  static TextStyle get title2 => TextStyle(fontSize: _textTitle2Size, height: _textTitle2Height, fontWeight: FontWeight.normal, color: textColor1);
  static TextStyle get title3 => TextStyle(fontSize: _textTitle3Size, height: _textTitle3Height, fontWeight: FontWeight.normal, color: textColor1);
  static TextStyle get headline => TextStyle(fontSize: _textHeadlineSize, height: _textHeadlineHeight, fontWeight: FontWeight.bold, color: textColor3);
  static TextStyle get subHeadline => TextStyle(fontSize: _textSubHeadlineSize, height: _textSubHeadlineHeight, fontWeight: FontWeight.normal, color: textColor2);
  static TextStyle get body => TextStyle(fontSize: _textBodySize, height: _textBodyHeight, fontWeight: FontWeight.normal, color: textColor2);
  static TextStyle get footnote => TextStyle(fontSize: _textCaptionFootnoteSize, height: _textCaptionFootnoteHeight, fontWeight: FontWeight.normal, color: textColor4);

  TextStyle _style() {
    switch (this) {

      case TextStyles.Title1:
        return title1;
      case TextStyles.Title2:
        return title2;
      case TextStyles.Title3:
        return title3;
      case TextStyles.Header:
        return headline;
      case TextStyles.SubHeader:
        return subHeadline;
      case TextStyles.Body:
        return body;
      case TextStyles.Footnote:
        return footnote;
    }
  }

  Text text(String text, {TextStyle Function(TextStyle style) applied}) {
    TextStyle t = style;
    if (applied != null) {
      t = applied(t);
    }
    return new Text(text, style: t);
  }

  ///UseCase: Header
  Text oswald(String content) {
    return text(content, applied: (s) => GoogleFonts.oswald(textStyle: s));
  }

  //UseCase: Body
  Text workSans(String content) {
    return text(content, applied: (s) => GoogleFonts.workSans(textStyle: s));
  }

  //UseCase: Code
  Text ubuntu(String content) {
    return text(content, applied: (s) => GoogleFonts.ubuntu(textStyle: s));
  }

  //UseCase: Universal
  Text roboto(String content) {
    return text(content, applied: (s) => GoogleFonts.roboto(textStyle: s));
  }

  //UseCase: Universal
  Text openSans(String content) {
    return text(content, applied: (s) => GoogleFonts.openSans(textStyle: s));
  }

  TextStyle get style => _style();

}

//Primary color swatch in discord-like colors
const MaterialColor primary = MaterialColor(
    0xFF36393f,
    {
      100: Color(0xFFFFFFFF),
      200: Color(0xFFb9bbbe),
      300: Color(0xFF83878b),
      400: Color(0xFF3a3e44),

      500: Color(0xFF36393f),

      600: Color(0xFF2f3136),
      700: Color(0xFF292b2f),
      800: Color(0xFF202225),
      900: Color(0xFF000000),
    }
);

//Modern accent colors
extension HueExt on Hues {

  Color get tined => _tinted();
  Color get hard => _hard();

  Color _tinted() {
    switch (this) {
      case Hues.Blue:
        return Color(0xFF7289da);
      case Hues.Red:
        return Color(0xFFD67171);
      case Hues.Green:
        return Color(0xFF72D883);
      case Hues.Yellow:
        return Color(0xFFD1C170);
      case Hues.Violet:
        return Color(0xFF9F6FCE);
      case Hues.Orange:
        return Color(0xFFCC9D6E);
    }
  }

  Color _hard() {
    switch (this) {

      case Hues.Blue:
        return Color(0xFF7289da);
      case Hues.Red:
        return Color(0xFFf04747);
      case Hues.Green:
        return Color(0xFF43b581);
      case Hues.Yellow:
        return Color(0xFFffcc4d);
      case Hues.Violet:
        return Color(0xFFff73fa);
      case Hues.Orange:
        return Color(0xFFFAA61A);
    }
  }

}

==> stylight-1.0.2.tar.gz: lib/stylight.dart <==
library stylight;

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

export 'website.dart';

part 'grid.dart';
part 'essentials.dart';

/*

Disclaimer:
Yes I know the TextTheme class, but i prefer having a "faster to implement" version for fast development

 */

class Sty {

  static final Sty sty = new Sty();

  // ignore: empty_constructor_bodies
  Sty() {

  }

  ThemeData get theme {
    return ThemeData(brightness: Brightness.dark, primarySwatch: primary, accentColor: Hues.Blue.hard, textTheme: textTheme, scaffoldBackgroundColor: primary[500]);
  }

}

enum Hues {

  Blue,
  Red,
  Green,
  Yellow,
  Violet,
  Orange

}

//Using these font colors will probably replace the requirement of opacity in text
Color get textColor1 => primary[100];
Color get textColor2 => primary[200];
Color get textColor3 => primary[300];
Color get textColor4 => primary[400];

enum TextStyles {

  Title1,
  Title2,
  Title3,
  Header,
  SubHeader,
  Body,
  Footnote

}

TextTheme get textTheme{
  return TextTheme(
      bodyText1: headline, bodyText2: body, subtitle1: subHeadline,
      subtitle2: subHeadline, headline6: headline, headline5: title3,
      headline4: title2, headline3: title1, headline2: title1,
      headline1: title1
  );
}


const double _textBodySize = 13;
const double _textBodyHeight = 16;

const double _textHeadlineSize = 13;
const double _textHeadlineHeight = 16;
const double _textSubHeadlineSize = 11;
const double _textSubHeadlineHeight = 14;

const double _textTitle3Size = 15;
const double _textTitle3Height = 20;
const double _textTitle2Size = 17;
const double _textTitle2Height = 22;
const double _textTitle1Size = 22;
const double _textTitle1Height = 26;

const double _textCaptionFootnoteSize = 10;
const double _textCaptionFootnoteHeight = 13;


TextStyle get title1 => TextStyle(fontSize: _textTitle1Size, height: _textTitle1Height, fontWeight: FontWeight.normal, color: textColor1);
TextStyle get title2 => TextStyle(fontSize: _textTitle2Size, height: _textTitle2Height, fontWeight: FontWeight.normal, color: textColor1);
TextStyle get title3 => TextStyle(fontSize: _textTitle3Size, height: _textTitle3Height, fontWeight: FontWeight.normal, color: textColor1);
TextStyle get headline => TextStyle(fontSize: _textHeadlineSize, height: _textHeadlineHeight, fontWeight: FontWeight.bold, color: textColor3);
TextStyle get subHeadline => TextStyle(fontSize: _textSubHeadlineSize, height: _textSubHeadlineHeight, fontWeight: FontWeight.normal, color: textColor2);
TextStyle get body => TextStyle(fontSize: _textBodySize, height: _textBodyHeight, fontWeight: FontWeight.normal, color: textColor2);
TextStyle get footnote => TextStyle(fontSize: _textCaptionFootnoteSize, height: _textCaptionFootnoteHeight, fontWeight: FontWeight.normal, color: textColor4);


extension TextStylesExt on TextStyles {

  TextStyle _style() {
    switch (this) {

      case TextStyles.Title1:
        return title1;
      case TextStyles.Title2:
        return title2;
      case TextStyles.Title3:
        return title3;
      case TextStyles.Header:
        return headline;
      case TextStyles.SubHeader:
        return subHeadline;
      case TextStyles.Body:
        return body;
      case TextStyles.Footnote:
        return footnote;
    }
  }

  Text text(String text, {TextStyle Function(TextStyle style) applied}) {
    TextStyle t = style;
    if (applied != null) {
      t = applied(t);
    }
    return new Text(text, style: t);
  }

  ///UseCase: Header
  Text oswald(String content) {
    return text(content, applied: (s) => GoogleFonts.oswald(textStyle: s));
  }

  //UseCase: Body
  Text workSans(String content) {
    return text(content, applied: (s) => GoogleFonts.workSans(textStyle: s));
  }

  //UseCase: Code
  Text ubuntu(String content) {
    return text(content, applied: (s) => GoogleFonts.ubuntu(textStyle: s));
  }

  //UseCase: Universal
  Text roboto(String content) {
    return text(content, applied: (s) => GoogleFonts.roboto(textStyle: s));
  }

  //UseCase: Universal
  Text openSans(String content) {
    return text(content, applied: (s) => GoogleFonts.openSans(textStyle: s));
  }

  TextStyle get style => _style();

}

//Primary color swatch in discord-like colors
const MaterialColor primary = MaterialColor(
    0xFF36393f,
    {
      100: Color(0xFFFFFFFF),
      200: Color(0xFFb9bbbe),
      300: Color(0xFF83878b),
      400: Color(0xFF3a3e44),

      500: Color(0xFF36393f),

      600: Color(0xFF2f3136),
      700: Color(0xFF292b2f),
      800: Color(0xFF202225),
      900: Color(0xFF000000),
    }
);

//Modern accent colors
extension HueExt on Hues {

  Color get tined => _tinted();
  Color get hard => _hard();

  Color _tinted() {
    switch (this) {
      case Hues.Blue:
        return Color(0xFF7289da);
      case Hues.Red:
        return Color(0xFFD67171);
      case Hues.Green:
        return Color(0xFF72D883);
      case Hues.Yellow:
        return Color(0xFFD1C170);
      case Hues.Violet:
        return Color(0xFF9F6FCE);
      case Hues.Orange:
        return Color(0xFFCC9D6E);
    }
  }

  Color _hard() {
    switch (this) {

      case Hues.Blue:
        return Color(0xFF7289da);
      case Hues.Red:
        return Color(0xFFf04747);
      case Hues.Green:
        return Color(0xFF43b581);
      case Hues.Yellow:
        return Color(0xFFffcc4d);
      case Hues.Violet:
        return Color(0xFFff73fa);
      case Hues.Orange:
        return Color(0xFFFAA61A);
    }
  }

}
